pub struct CommonStorageOptions {Show 17 fields
pub storage_max_concurrent_queries: Option<usize>,
pub storage_max_stream_queries: usize,
pub storage_max_cache_size: usize,
pub storage_max_value_entry_size: usize,
pub storage_max_find_keys_entry_size: usize,
pub storage_max_find_key_values_entry_size: usize,
pub storage_max_cache_entries: usize,
pub storage_max_cache_value_size: usize,
pub storage_max_cache_find_keys_size: usize,
pub storage_max_cache_find_key_values_size: usize,
pub blob_cache_size: usize,
pub confirmed_block_cache_size: usize,
pub certificate_cache_size: usize,
pub certificate_raw_cache_size: usize,
pub event_cache_size: usize,
pub cache_cleanup_interval_secs: u64,
pub storage_replication_factor: u32,
}Fields
storage_max_concurrent_queries: Option<usize>The maximal number of simultaneous queries to the database
storage_max_stream_queries: usizeThe maximal number of simultaneous stream queries to the database
storage_max_cache_size: usizeThe maximal memory used in the storage cache.
storage_max_value_entry_size: usizeThe maximal size of a value entry in the storage cache.
storage_max_find_keys_entry_size: usizeThe maximal size of a find-keys entry in the storage cache.
storage_max_find_key_values_entry_size: usizeThe maximal size of a find-key-values entry in the storage cache.
storage_max_cache_entries: usizeThe maximal number of entries in the storage cache.
storage_max_cache_value_size: usizeThe maximal memory used in the value cache.
storage_max_cache_find_keys_size: usizeThe maximal memory used in the find_keys_by_prefix cache.
storage_max_cache_find_key_values_size: usizeThe maximal memory used in the find_key_values_by_prefix cache.
blob_cache_size: usizeThe maximal number of entries in the blob cache.
confirmed_block_cache_size: usizeThe maximal number of entries in the confirmed block cache.
certificate_cache_size: usizeThe maximal number of entries in the assembled certificate cache.
certificate_raw_cache_size: usizeThe maximal number of entries in the raw certificate cache.
event_cache_size: usizeThe maximal number of entries in the event cache.
cache_cleanup_interval_secs: u64Interval in seconds between weak reference cleanup sweeps in value caches.
storage_replication_factor: u32The replication factor for the keyspace
Implementations
Sourceimpl CommonStorageOptions
impl CommonStorageOptions
pub fn with_defaults() -> CommonStorageOptions
pub fn storage_cache_config(&self) -> StorageCacheConfig
pub fn views_storage_cache_config(&self) -> StorageCacheConfig