pub trait RunnableWithStore {
type Output;
// Required method
fn run<'async_trait, D>(
self,
config: <D as KeyValueDatabase>::Config,
namespace: String,
cache_sizes: StorageCacheConfig,
) -> Pin<Box<dyn Future<Output = Result<Self::Output, Error>> + Send + 'async_trait>>
where D: KeyValueDatabase + Clone + Send + Sync + 'static + 'async_trait,
<D as KeyValueDatabase>::Store: KeyValueStore + Clone + Send + Sync + 'static,
<D as WithError>::Error: Send + Sync,
Self: 'async_trait;
}Expand description
A job that can be run against a low-level key-value store.
Required Associated Types
Required Methods
Sourcefn run<'async_trait, D>(
self,
config: <D as KeyValueDatabase>::Config,
namespace: String,
cache_sizes: StorageCacheConfig,
) -> Pin<Box<dyn Future<Output = Result<Self::Output, Error>> + Send + 'async_trait>>where
D: KeyValueDatabase + Clone + Send + Sync + 'static + 'async_trait,
<D as KeyValueDatabase>::Store: KeyValueStore + Clone + Send + Sync + 'static,
<D as WithError>::Error: Send + Sync,
Self: 'async_trait,
fn run<'async_trait, D>(
self,
config: <D as KeyValueDatabase>::Config,
namespace: String,
cache_sizes: StorageCacheConfig,
) -> Pin<Box<dyn Future<Output = Result<Self::Output, Error>> + Send + 'async_trait>>where
D: KeyValueDatabase + Clone + Send + Sync + 'static + 'async_trait,
<D as KeyValueDatabase>::Store: KeyValueStore + Clone + Send + Sync + 'static,
<D as WithError>::Error: Send + Sync,
Self: 'async_trait,
Runs the job against a store built from the given configuration.
Dyn Compatibility
This trait is not dyn compatible.
In older versions of Rust, dyn compatibility was called "object safety", so this trait is not object safe.